package cz.zweistein.df.soundsense.player;

import java.io.FileInputStream;
import java.io.InputStream;
import java.util.logging.Logger;

import cz.zweistein.df.soundsense.config.Sound;
import cz.zweistein.df.soundsense.util.LoggerSource;

import javazoom.jl.player.Player;

public class ChannelThread implements Runnable {
	private static Logger logger = LoggerSource.logger;
	
	private Player musicPlayer;
	private Sound loopMusic;
	private String currentMusic;
	private boolean temporaryLoopDisable;
	
	private String channelName;

	public ChannelThread(String channelName) {
		this.channelName = channelName;
	}

	public void setTemporaryLoopDisable(boolean temporaryLoopDisable) {
		this.temporaryLoopDisable = temporaryLoopDisable;
	}

	public void setLoopMusic(Sound sound) {
		this.loopMusic = sound;
	}

	public void setCurrentMusic(String sound) {
		this.currentMusic = sound;
	}

	public Player getMusicPlayer() {
		return this.musicPlayer;
	}

	@Override
	public void run() {
		
		while(true) {
			
			try {
				
				if (currentMusic != null) {
			
					logger.finest("Opening "+currentMusic);
					InputStream in = new FileInputStream(currentMusic);
		
					musicPlayer = new Player(in);
					
					logger.fine(channelName+": "+currentMusic);
					musicPlayer.play();
					
					if (!temporaryLoopDisable) {
						if (loopMusic != null) {
							currentMusic = loopMusic.getSoundFile();
							logger.fine("Looping "+channelName+": "+currentMusic);
						} else {
							currentMusic = null;
						}
					} else {
						if (loopMusic == null) {
							currentMusic = null;
						}
						temporaryLoopDisable = false;
					}
				
				} else {
					Thread.sleep(100);
				}
			
			} catch (Exception e) {
				logger.severe(e.toString());
				try {
					Thread.sleep(100);
				} catch (InterruptedException e1) {
				}
			}
			
			
		} 
		
	}

}
