package cz.zweistein.df.soundsense.player;

import java.util.HashMap;
import java.util.Map;
import java.util.logging.Logger;

import cz.zweistein.df.soundsense.config.Loop;
import cz.zweistein.df.soundsense.config.Sound;
import cz.zweistein.df.soundsense.util.LoggerSource;


public class PlayerManager {
	private static Logger logger = LoggerSource.logger;
	
	public int concurentSounds;
	private Map<String, ChannelThread> channels;
	
	public PlayerManager() {
		this.channels = new HashMap<String, ChannelThread>();
		
		this.concurentSounds = 0;
	}

	public void playSound(Sound sound) {
		
		if (sound.getChannel() == null) {
			if (sound.getConcurency() == null || (sound.getConcurency() != null && concurentSounds < sound.getConcurency())) {
				MP3Thread mp3Thread = new MP3Thread(this, sound.getSoundFile());
				new Thread(mp3Thread).start();
			} else {
				logger.fine("Dropped sound for "+sound.getLogPattern()+" its concurency is "+sound.getConcurency()+" and there are "+concurentSounds+" sounds playing.");
			}
		} else  {
			
			ChannelThread channelThread = this.getChannel(sound.getChannel());
			
			if (sound.getLoop() == Loop.START_LOOPING) {
				channelThread.setLoopMusic(sound);
			} else if (sound.getLoop() == Loop.STOP_LOOPING) {
				channelThread.setLoopMusic(null);
				logger.fine("Stopped looping "+sound.getChannel()+".");
			}
			channelThread.setCurrentMusic(sound.getSoundFile());
			channelThread.setTemporaryLoopDisable(true);
				
			if (channelThread.getMusicPlayer() != null) {
				channelThread.getMusicPlayer().close();
			}
		}
		
	}

	private ChannelThread getChannel(String channel) {
		ChannelThread channelThread = this.channels.get(channel);
		if (channelThread == null) {
			channelThread = new ChannelThread(channel);
			this.channels.put(channel, channelThread);
			new Thread(channelThread).start();
		}
		return channelThread;
	}

}
